<?php

namespace Drupal\Tests\moderation_moderation_scheduler\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Test covering the ModerationScheduler.
 *
 * @group moderation_scheduler
 */
class ModerationSchedulerFunctionalTest extends BrowserTestBase {

  /**
   * User.
   *
   * @var \Drupal\user\Entity\User
   */
  protected $user;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    $this->drupalCreateContentType([
      'type' => 'page',
      'name' => 'Basic page',
    ])
      ->save();

    $workflow = $this->createEditorialWorkflow();
    $workflow->getTypePlugin()->addEntityTypeAndBundle('node', 'page');
    $workflow->save();

    $this->user = $this->drupalCreateUser([
      'access content',
      'create page content',
      'edit own page content',
      'administer moderation_scheduler module',
      'view latest version',
      'view any unpublished content',
      'access content overview',
    ]);
  }

  /**
   * Test ModerationScheduler.
   */
  public function testModerationScheduler() {
    $this->drupalLogin($this->user);

    // Create a node and publish it using the "publish" transition.
    $edit = [
      'title[0][value]' => $this->randomString(),
    ];
    $this->drupalPostForm('node/add/page', $edit, t('Save'));

    $node = $this->drupalGetNodeByTitle($edit['title[0][value]']);

    $timestamp = REQUEST_TIME - 87654321;
    $date_field = DrupalDateTime::createFromTimestamp($timestamp, 'UTC');

    // Change node moderation state to publish.
    $edit = [
      'field_scheduled_time' => $date_field,
    ];
    $this->drupalPostForm('node/' . $node->id() . '/edit', $edit, t('Save'));

    $this->assertSession()->pageTextContains('This revision is scheduled in the past and will be published with next cron execution');
  }

}
